@@ -30,7 +30,6 @@
 #include "ephy-lockdown.h"
 #include "ephy-extension.h"
 #include "ephy-settings.h"
-#include "ephy-toolbar.h"
 #include "ephy-prefs.h"
 #include "ephy-debug.h"
 
@@ -68,7 +67,6 @@ arbitrary_url_cb (GSettings *settings,
 		  EphyWindow *window)
 {
 	EphyEmbed *embed;
-	GtkWidget *toolbar;
 	char *address;
 
 	/* Restore the real web page address when disabling entry */
@@ -79,9 +77,8 @@ arbitrary_url_cb (GSettings *settings,
 		if (embed == NULL)
 			return;
 
-		toolbar = ephy_window_get_toolbar (window);
 		address = ephy_web_view_get_location (ephy_embed_get_web_view (embed), TRUE);
-		ephy_toolbar_set_location (EPHY_TOOLBAR (toolbar), address);
+		ephy_window_set_location (window, address);
 		ephy_web_view_set_typed_address (ephy_embed_get_web_view (embed), NULL);
 		g_free (address);
 	}
@@ -111,8 +108,6 @@ static const BindAction window_actions[] = {
 	{ EPHY_PREFS_LOCKDOWN_PRINT_SETUP, "FilePrintSetup", "sensitive" },
 	{ EPHY_PREFS_LOCKDOWN_COMMAND_LINE, "FilePrintSetup", "sensitive" },
 
-	{ EPHY_PREFS_LOCKDOWN_TOOLBAR_EDITING, "ViewToolbarEditor", "sensitive" },
-
 	{ EPHY_PREFS_LOCKDOWN_BOOKMARK_EDITING, "GoBookmarks", "sensitive" },
 	{ EPHY_PREFS_LOCKDOWN_BOOKMARK_EDITING, "FileBookmarkPage", "sensitive" },
 
@@ -144,12 +139,6 @@ static const BindAction special_toolbar_actions[] = {
 	{ EPHY_PREFS_LOCKDOWN_FULLSCREEN, "FileNewWindow", "sensitive" }
 };
 
-static const BindAction toolbar_actions[] = {
-	{ EPHY_PREFS_LOCKDOWN_TOOLBAR_EDITING, "MoveToolItem", "sensitive" },
-	{ EPHY_PREFS_LOCKDOWN_TOOLBAR_EDITING, "RemoveToolItem", "sensitive" },
-	{ EPHY_PREFS_LOCKDOWN_TOOLBAR_EDITING, "RemoveToolbar", "sensitive" }
-};
-
 static gboolean
 sensitive_get_mapping (GValue *value,
 		       GVariant *variant,
@@ -259,11 +248,6 @@ impl_attach_window (EphyExtension *extension,
 	bind_settings_and_actions (EPHY_SETTINGS_LOCKDOWN,
 				   action_group, special_toolbar_actions,
 				   G_N_ELEMENTS (special_toolbar_actions));
-
-	action_group = find_action_group (manager, "ToolbarActions");
-	bind_settings_and_actions (EPHY_SETTINGS_LOCKDOWN,
-				   action_group, toolbar_actions,
-				   G_N_ELEMENTS (toolbar_actions));
 }
 
 static void
