@@ -23,10 +23,8 @@
 #include "config.h"
 #include "ephy-shell.h"
 
-#include "egg-toolbars-model.h"
 #include "ephy-bookmarks-editor.h"
 #include "ephy-bookmarks-import.h"
-#include "ephy-bookmarks-ui.h"
 #include "ephy-debug.h"
 #include "ephy-embed-container.h"
 #include "ephy-embed-single.h"
@@ -41,8 +39,6 @@
 #include "ephy-profile-utils.h"
 #include "ephy-session.h"
 #include "ephy-settings.h"
-#include "ephy-toolbar.h"
-#include "ephy-toolbars-model.h"
 #include "ephy-type-builtins.h"
 #include "ephy-web-view.h"
 #include "ephy-window.h"
@@ -58,8 +54,6 @@ struct _EphyShellPrivate {
   EphySession *session;
   GObject *lockdown;
   EphyBookmarks *bookmarks;
-  EggToolbarsModel *toolbars_model;
-  EggToolbarsModel *fs_toolbars_model;
   EphyExtensionsManager *extensions_manager;
   GNetworkMonitor *network_monitor;
   GtkWidget *bme;
@@ -500,37 +494,25 @@ ephy_shell_dispose (GObject *object)
 
   if (shell->priv->extensions_manager != NULL) {
     LOG ("Unref extension manager");
-    /* this will unload the extens  ions */
+    /* this will unload the extensions */
     g_object_unref (priv->extensions_manager);
     priv->extensions_manager = NULL;
   }
 
   if (priv->session != NULL) {
-    LOG ("Unref session ma  nager");
+    LOG ("Unref session manager");
     g_object_unref (priv->session);
     priv->session = NULL;
   }
 
   if (priv->lockdown != NULL) {
-    LOG ("Unref lockdown co ntroller");
+    LOG ("Unref lockdown controller");
     g_object_unref (priv->lockdown);
     priv->lockdown = NULL;
   }
 
-  if (priv->toolbars_model != NULL) {
-    LOG ("Unref toolbars model");
-    g_object_unref (priv->toolbars_model);
-    priv->toolbars_model = NULL;
-  }
-
-  if (priv->fs_toolbars_model != NULL) {
-    LOG ("Unref fullscreen toolbars   model");
-    g_object_unref (priv->fs_toolbars_model);
-    priv->fs_toolbars_model = NULL;
-  }
-
   if (priv->bme != NULL) {
-    LOG ("Unref Bookma  rks Editor");
+    LOG ("Unref Bookmarks Editor");
     gtk_widget_destroy (GTK_WIDGET (priv->bme));
     priv->bme = NULL;
   }
@@ -631,7 +613,6 @@ ephy_shell_new_tab_full (EphyShell *shell,
   GtkWidget *nb;
   int position = -1;
   gboolean is_empty = FALSE;
-  EphyToolbar *toolbar;
 
   if (flags & EPHY_NEW_TAB_OPEN_PAGE) open_page = TRUE;
   if (flags & EPHY_NEW_TAB_IN_NEW_WINDOW) in_new_window = TRUE;
@@ -655,13 +636,14 @@ ephy_shell_new_tab_full (EphyShell *shell,
     window = ephy_window_new_with_chrome (chrome, is_popup);
   }
 
-  toolbar = EPHY_TOOLBAR (ephy_window_get_toolbar (window));
-
-  if ((flags & EPHY_NEW_TAB_APPEND_AFTER) && previous_embed != NULL) {
-    nb = ephy_window_get_notebook (window);
-    /* FIXME this assumes the tab is the  direct notebook child */
-    position = gtk_notebook_page_num (GTK_NOTEBOOK (nb),
-                                      GTK_WIDGET (previous_embed)) + 1;
+  if (flags & EPHY_NEW_TAB_APPEND_AFTER) {
+    if (previous_embed) {
+      nb = ephy_window_get_notebook (window);
+      /* FIXME this assumes the tab is the  direct notebook child */
+      position = gtk_notebook_page_num (GTK_NOTEBOOK (nb),
+                                        GTK_WIDGET (previous_embed)) + 1;
+    } else
+      g_warning ("Requested to append new tab after parent, but 'previous_embed' was NULL");
   }
 
   if (flags & EPHY_NEW_TAB_FROM_EXTERNAL) {
@@ -702,8 +684,9 @@ ephy_shell_new_tab_full (EphyShell *shell,
       flags & EPHY_NEW_TAB_NEW_PAGE) {
     EphyWebView *view = ephy_embed_get_web_view (embed);
     ephy_web_view_set_typed_address (view, "");
-    ephy_toolbar_activate_location (toolbar);
-    is_empty = ephy_web_view_load_homepage (view);
+    ephy_window_activate_location (window);
+    ephy_web_view_load_homepage (view);
+    is_empty = TRUE;
   } else if (flags & EPHY_NEW_TAB_OPEN_PAGE) {
     ephy_web_view_load_request (ephy_embed_get_web_view (embed),
                                 request);
@@ -719,8 +702,7 @@ ephy_shell_new_tab_full (EphyShell *shell,
      * page was a copy */
     if (is_empty) {
       /* empty page, focus location entry */
-      toolbar = EPHY_TOOLBAR (ephy_window_get_toolbar (window));
-      ephy_toolbar_activate_location (toolbar);
+      ephy_window_activate_location (window);
     } else if (embed != NULL) {
       /* non-empty page, focus the page. but make sure the widget is realised first! */
       gtk_widget_realize (GTK_WIDGET (embed));
@@ -832,52 +814,6 @@ ephy_shell_get_bookmarks (EphyShell *shell)
   return shell->priv->bookmarks;
 }
 
-/**
- * ephy_shell_get_toolbars_model:
- *
- * Return value: (transfer none):
- **/
-GObject *
-ephy_shell_get_toolbars_model (EphyShell *shell, gboolean fullscreen)
-{
-  LOG ("ephy_shell_get_toolbars_model fs=%d", fullscreen);
-
-  if (fullscreen) {
-    if (shell->priv->fs_toolbars_model == NULL) {
-      EggTbModelFlags flags;
-      gboolean success;
-      const char *xml;
-
-      shell->priv->fs_toolbars_model = egg_toolbars_model_new ();
-      xml = ephy_file ("epiphany-fs-toolbar.xml");
-      g_return_val_if_fail (xml != NULL, NULL);
-
-      success = egg_toolbars_model_load_toolbars
-        (shell->priv->fs_toolbars_model, xml);
-      g_return_val_if_fail (success, NULL);
-
-      flags = egg_toolbars_model_get_flags
-        (shell->priv->fs_toolbars_model, 0);
-      egg_toolbars_model_set_flags
-        (shell->priv->fs_toolbars_model, 0,
-         flags | EGG_TB_MODEL_NOT_REMOVABLE);
-    }
-
-    return G_OBJECT (shell->priv->fs_toolbars_model);
-  } else {
-    if (shell->priv->toolbars_model == NULL) {
-      shell->priv->toolbars_model = ephy_toolbars_model_new ();
-
-      ephy_bookmarks_ui_attach_toolbar_model (shell->priv->toolbars_model);
-
-      ephy_toolbars_model_load
-        (EPHY_TOOLBARS_MODEL (shell->priv->toolbars_model));
-    }
-
-    return G_OBJECT (shell->priv->toolbars_model);
-  }
-}
-
 /**
  * ephy_shell_get_extensions_manager:
  *
