@@ -21,45 +21,43 @@
  */
 
 #include "config.h"
+#include "window-commands.h"
 
-#include "ephy-embed.h"
+#include "ephy-bookmarks-editor.h"
+#include "ephy-bookmarks-ui.h"
+#include "ephy-debug.h"
+#include "ephy-dialog.h"
 #include "ephy-embed-container.h"
+#include "ephy-embed-prefs.h"
 #include "ephy-embed-shell.h"
 #include "ephy-embed-single.h"
 #include "ephy-embed-utils.h"
-#include "ephy-shell.h"
-#include "ephy-debug.h"
-#include "window-commands.h"
-#include "ephy-prefs.h"
-#include "ephy-settings.h"
-#include "ephy-embed-prefs.h"
-#include "ephy-dialog.h"
-#include "ephy-bookmarks-editor.h"
-#include "ephy-history-window.h"
+#include "ephy-embed.h"
 #include "ephy-file-chooser.h"
 #include "ephy-file-helpers.h"
-#include "ephy-toolbar.h"
-#include "ephy-state.h"
-#include "ephy-gui.h"
-#include "ephy-zoom.h"
-#include "ephy-notebook.h"
-#include "ephy-toolbar-editor.h"
 #include "ephy-find-toolbar.h"
-#include "ephy-location-entry.h"
-#include "ephy-bookmarks-ui.h"
+#include "ephy-gui.h"
+#include "ephy-history-window.h"
 #include "ephy-link.h"
+#include "ephy-location-entry.h"
+#include "ephy-notebook.h"
+#include "ephy-prefs.h"
+#include "ephy-settings.h"
+#include "ephy-shell.h"
+#include "ephy-state.h"
 #include "ephy-stock-icons.h"
 #include "ephy-string.h"
-#include "pdm-dialog.h"
 #include "ephy-web-app-utils.h"
+#include "ephy-zoom.h"
+#include "pdm-dialog.h"
 
-#include <string.h>
-#include <glib.h>
 #include <gio/gio.h>
-#include <gtk/gtk.h>
+#include <glib.h>
 #include <glib/gi18n.h>
-#include <webkit/webkit.h>
+#include <gtk/gtk.h>
 #include <libnotify/notify.h>
+#include <string.h>
+#include <webkit/webkit.h>
 
 static void
 page_setup_done_cb (GtkPageSetup *setup,
@@ -889,9 +887,6 @@ void
 window_cmd_view_fullscreen (GtkAction *action,
 			    EphyWindow *window)
 {
-	/* Otherwise the other toolbar layout shows briefly while switching */
-	gtk_widget_hide (ephy_window_get_toolbar (window));
-
 	if (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)))
 	{
 		GtkWidget *toolbar_editor;
@@ -1203,14 +1198,6 @@ window_cmd_edit_personal_data (GtkAction *action,
 	g_free (host);
 }
 
-#if 0
-void
-window_cmd_edit_certificates (GtkAction *action,
-			      EphyWindow *window)
-{
-}
-#endif
-
 void
 window_cmd_edit_prefs (GtkAction *action,
 		       EphyWindow *window)
@@ -1222,13 +1209,6 @@ window_cmd_edit_prefs (GtkAction *action,
 	ephy_dialog_show (dialog);
 }
 
-void
-window_cmd_edit_toolbar (GtkAction *action,
-			 EphyWindow *window)
-{
-	ephy_toolbar_editor_show (window);
-}
-
 void
 window_cmd_help_contents (GtkAction *action,
 			 EphyWindow *window)
@@ -1463,11 +1443,9 @@ void
 window_cmd_load_location (GtkAction *action,
 			  EphyWindow *window)
 {
-	EphyToolbar *toolbar;
 	const char *location;
 
-	toolbar = EPHY_TOOLBAR (ephy_window_get_toolbar (window));
-	location = ephy_toolbar_get_location (toolbar);
+	location = ephy_window_get_location (window);
 
 	if (location)
 	{
